function [oxc_sw_stat,add_ports,drop_ports,oxc_sw_pwr,call_blocked_q]=configOXC(oxc_sw_stat,rt,mdn,wave_no,FiberPort,add_ports,drop_ports,oxc_sw_pwr,Topo_No)

% This function configures the OXC switch for agiven LP route on a % wavelength.
% This function updates the oxc_sw_stat matrix for the given rt=route
% oxc_sw_stat matrix is a four dimentional array of size (N,N,wave_no,nds)
% Row of oxc_sw_stat(:,:,wave_no,nds)=Input port
% Column of oxc_sw_stat(:,:,wave_no,nds)=Output port
% add_ports=zeros(num_of_wavelengths,np_sd,nds) 
% drop_ports=zeros(num_of_wavelengths,np_sd,nds)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[DisMat, number_of_links,nds,num_of_wavelengths,q_th,max_degree,RT_METHOD,num_of_des,wave_assginment]=constants(Topo_No);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%CONSTANTS
mm=1e-3;
c=3e8; 
[N,np_sd,Be,Bo,tx_pw,L_mx,L_dm,L_s,L_w,L_sw,L_tap,l,L,Xsw,Gin_max,Gout_max,G_dB,lambda_array,nsp,h,alpha]=parameters(max_degree,num_of_wavelengths);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lambda=lambda_array(wave_no);
f_lam=c/lambda; % Carrier frequency in Hz
P_n = 2*nsp*h*f_lam*Bo/mm; % This is a constant used in the calculation of ASE power in mW
%**************************************************************************
nh=length(mdn); % Is the number of hops the signal traverses before reaching the destination.
if (l~=0)
    A=ceil(mdn./l)-1; % This the number of amplifiers placed between the link for each fiber. 
else
    A=zeros(1,length(mdn)); % There are no in-line amplifiers
end
UnComp_l=mdn-A.*l; % This is the uncompensated length of the fiber, for this there is a loss due to attenuation of the fiber.
p_out=zeros(1,nh+1); % Pout Matrix in mW
p_out(1,1)=tx_pw; % Intializing the input power in dBm.
p_out_m(1,1)=10^(p_out(1,1)/10); % In mW
p_ase_m(1,1)=P_n*(10^(Gin_max/10)-1)*10^(-L_mx/10)*10^(-L_dm/10)*10^(-L_sw/10)*10^(Gout_max/10)*10^(-L_tap/10)+P_n*(10^(Gout_max/10)-1)*10^(-L_tap/10);
p_ase_node=P_n*(10^(Gin_max/10)-1)*10^(-L_mx/10)*10^(-L_dm/10)*10^(-L_sw/10)*10^(Gout_max/10)*10^(-L_tap/10)+P_n*(10^(Gout_max/10)-1)*10^(-L_tap/10);

%%% For calculating the cross talk first we need the cross talk terms at the switch we are using.

%%% Assign Input Port at Source Node %%%%%%%%%

%oxc_sw_stat(:,:,wave_no,rt(1)); % This is the OXC switch status matrix corresponding to the source node and given wavelength number
for i=1:np_sd
    if add_ports(wave_no,i,rt(1))==0 % At the source node assign the first available input port.
        add_ports(wave_no,i,rt(1))=1;
       break
    end
end
% i; % This is the input port number of the OXC(wave_no) at rt(1); That is channel is added
%FiberPort(rt(1),rt(2));
oxc_sw_stat(i,FiberPort(rt(1),rt(2)),wave_no,rt(1))=1; % The output port at rt(1) after adding the channel is found by the map of FiberPort
%%%%%%%% Note that oxc_sw_pwr matrix is in mW %%%%%%%%
%i
%FiberPort(rt(1),rt(2))
oxc_sw_pwr(i,FiberPort(rt(1),rt(2)),wave_no,rt(1))=p_out_m(1,1); % Power at the source 1 mW = 0dB
[SD_pairs,num_of_inter]=nxt(i,FiberPort(rt(1),rt(2)),N); % Crosstalk terms for a given primary port numbers
pxt_m(1,1)=0;
for m=1:num_of_inter
    pxt_m(1,1)=pxt_m(1,1)+Xsw*oxc_sw_pwr(SD_pairs(m,1),SD_pairs(m,2),wave_no,rt(1))*10^(-L_sw/10)*10^(-L_mx/10)*10^(Gout_max/10)*10^(-L_tap/10);
end
%%%%%%%%%%%%%%%%%%%%%%%%%%% Intermediate node %%%%%%%%%%%%%%%%%%%%%%
if length(rt)>2
   for j=2:length(rt)-1 % Until the node before to the destination node
       p_out(1,j)=(p_out(1,j-1)+Gin_max+Gout_max)-(L_sw + L_mx+2*L_tap+L*UnComp_l(1,j-1)+L_dm); % AGC Model
       p_out_m(1,j)=10^(p_out(1,j)/10);
       p_ase_m(1,j)=p_ase_m(1,j-1)*exp(-alpha*UnComp_l(1,j-1))*10^(-L_tap/10)*10^(Gin_max/10)*10^(-L_dm/10)*10^(-L_sw/10)*10^(-L_mx/10)...
                    *10^(Gout_max/10)*10^(-L_tap/10)+P_n*(10^(G_dB/10)-1)*A(1,j-1)+p_ase_node;
       oxc_sw_stat(FiberPort(rt(j-1),rt(j)),FiberPort(rt(j),rt(j+1)),wave_no,rt(j))=1;
       oxc_sw_pwr(FiberPort(rt(j-1),rt(j)),FiberPort(rt(j),rt(j+1)),wave_no,rt(j))=p_out_m(1,j);
       oxc_sw_pwr(:,:,wave_no,rt(j));
       [SD_pairs,num_of_inter]=nxt(FiberPort(rt(j-1),rt(j)),FiberPort(rt(j),rt(j+1)),N);
       pxt_nd_m=0; % Power of the cross-talk terms
       for m=1:num_of_inter
           pxt_nd_m=pxt_nd_m+Xsw*oxc_sw_pwr(SD_pairs(m,1),SD_pairs(m,2),wave_no,rt(j))*10^(-L_sw/10)*10^(-L_mx/10)*10^(Gout_max/10)*10^(-L_tap/10);
       end
       %pxt_nd_m;
       pxt_m(1,j)=pxt_m(1,j-1)*exp(-alpha*UnComp_l(1,j-1))*10^(-L_tap/10)*10^(Gin_max/10)*10^(-L_dm/10)*10^(-L_sw/10)*10^(-L_mx/10)...
                    *10^(Gout_max/10)*10^(-L_tap/10)+pxt_nd_m;
   end
  % j+1; % =length(rt)
else
    j=1; % When the LP is a single hop than the next-hop node is the destination
end

%%%%%%%%%%%%%%%%%%%%% Assign Output Port at Destination Node %%%%%%%%%%%%%%%%%%%%
for k=1:np_sd
    if drop_ports(wave_no,k,rt(j+1))==0 % At the source node assign the first available output port.
       drop_ports(wave_no,k,rt(j+1))=1;
       break
    end
end
% k;
p_out(1,j+1)=(p_out(1,j)+Gin_max+Gout_max)-(L_sw + L_mx+2*L_tap+L*UnComp_l(1,j)+L_dm); % AGC Model
p_out_m(1,j+1)=10^(p_out(1,j+1)/10);
p_ase_m(1,j+1)=p_ase_m(1,j)*exp(-alpha*UnComp_l(1,j))*10^(-L_tap/10)*10^(Gin_max/10)*10^(-L_dm/10)*10^(-L_sw/10)*10^(-L_mx/10)...
                    *10^(Gout_max/10)*10^(-L_tap/10)+P_n*(10^(G_dB/10)-1)*A(1,j)+p_ase_node;
oxc_sw_stat(FiberPort(rt(j),rt(j+1)),k,wave_no,rt(j+1))=1;
oxc_sw_pwr(FiberPort(rt(j),rt(j+1)),k,wave_no,rt(j+1))=p_out_m(1,j+1); % Power at the destination
[SD_pairs,num_of_inter]=nxt(FiberPort(rt(j),rt(j+1)),k,N); % Crosstalk terms for a given primary port numbers
pxt_nd_m=0;
for m=1:num_of_inter
    pxt_nd_m=pxt_nd_m+Xsw*oxc_sw_pwr(SD_pairs(m,1),SD_pairs(m,2),wave_no,rt(j+1))*10^(-L_sw/10)*10^(-L_mx/10)*10^(Gout_max/10)*10^(-L_tap/10);
end
pxt_m(1,j+1)=pxt_m(1,j)*exp(-alpha*UnComp_l(1,j))*10^(-L_tap/10)*10^(Gin_max/10)*10^(-L_dm/10)*10^(-L_sw/10)*10^(-L_mx/10)...
                    *10^(Gout_max/10)*10^(-L_tap/10)+pxt_nd_m;
%p_out_m;
%pxt_m;
osnr=p_out_m./(p_ase_m+pxt_m); % Optical Signal to Noise ratio.
q=(2*sqrt(Bo/Be).*osnr)./(1+sqrt(1+4.*osnr));
%q;
for i=1:length(q)
    if q(i)<q_th % q-factor at the final node
       call_blocked_q=true;
       break
    else
       call_blocked_q=false;
    end
end
%call_blocked_q;



