function FiberPort=crosstalk(Topo_No)
% Start Date: 23 Nov 2009
% End Date: Inf
% The usage of the OXC ports is as follows:
% Port np,np-1,np-2.... : For intermediate node
% Remaining ports for add drop channel
% Note that the port numbers are labeled as below
%        __________ 
%  8 ---|          |--- 8
%  7 ---|          |--- 7
%  6 ---|          |--- 6
%  5 ---|  OXC     |--- 5
%  4 ---|          |--- 4
%  3 ---|          |--- 3
%  2 ---|          |--- 2
%  1 ---|__________|--- 1
%%%%%%%%%%%%%% OXC_SW_STATUS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% The typical matrix looks like this %%%%%%%%%%%%%%%%
% np_sd=N-max_degree; % This is the number of input/output ports that can be used for add/drop by any OXC in the entire network
%                                                    1  2   3 ..... N-np_sd  ......    N
%                                                    --                                --                     
%                                            1      |                   | This submatrix |     
%                                            2      |  This submatrix   | will be used   |                                           
%                                            3      |  will have all    | for adding     |
%                                            .      |  zeros            | channel        |
%                                            .      |                   |                |
% OXC_SW_STATUS(:,:,wave_no,node_no)=     N-np_sd   |-------------------+----------------|
%                                            .      | This submtrix     | This submatrix |
%                                            .      | will be used      | used for       |
%                                            .      | for drooping      | intermediate   |
%                                            .      | channel           | nodes          |
%                                            N      |                                    |
%                                                    --                                --                     
%[DisMat, number_of_links,nds,num_of_wavelengths]=constants(Topo_No);
% In NSF network we use each OXC 8 x 8 since there are nodes with in/out nodal degree 4. So we need at least 4 add/drop ports apart from the
% intermediate nodes.
% The switch size is decided by the maximum nodal degree (either in or out in the case of bi-directional fibers at every node this degree is same).
% Hence the number of ports in the OXC switch for the bi-directional network should be atleast 2^n >=(2*max_nodal_degree) for the minimum 'n'. For
% example in NSF maximum nodal degree is 4 (Node:9 and Node:6) Hence we must atleast have eight ports and hence the switch size needed is 8 x 8
[DisMat,number_of_links,nds,max_degree]=phy_topology(Topo_No);
%%%%%%%% OXC Switch Size %%%%
N=2^(ceil(log2(2*max_degree))); % OXC switch size in the network architecture N >= log2(2*max_degree)
FiberPort=zeros(nds); % This matrix gives the connectivity of the fiber to the output port of OXC (same for all wavelengths) for give s-d pair
                      % Example FiberPort(1,2)=8 denotes that the fiber from node-1 to node-2 is connected at output port-8 of OXC('s).
for i=1:nds
    PoNu=N;
    for j=1:nds
        if DisMat(i,j)~=0
           FiberPort(i,j)=PoNu; % Port Number
           PoNu=PoNu-1;
        end
    end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%        

