function [oxc_sw_stat,oxc_sw_pwr,add_ports,drop_ports]=deconfigOXC(oxc_sw_stat,oxc_sw_pwr,rt,wave_no,FiberPort,max_degree,add_ports,drop_ports)
% This function configures the OXC switch for agiven LP route on a % wavelength.
% This function updates the oxc_sw_stat matrix for the given rt=route
% oxc_sw_stat matrix is a four dimentional array of size (N,N,wave_no,nds)
% Row of oxc_sw_stat(:,:,wave_no,nds)=Input port
% Column of oxc_sw_stat(:,:,wave_no,nds)=Output port
% add_ports=zeros(num_of_wavelengths,np_sd,nds)
% drop_ports=zeros(num_of_wavelengths,np_sd,nds)
N=2^(ceil(log2(2*max_degree))); % Switch size N x N
np_sd=N-max_degree; % This is the number of input/output ports that can be used for add/drop by any OXC in the entire network
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% While removing the configured LP in the OXC switches at the source node  we know the output port from the FiberPort Matrix 
% {FiberPort(rt(1),rt(2))=output port},  however for knowing  the port at which the channel is added is to find the entry 1 (which is unique) 
% at 1 to np_sd columns of oxc_sw_stat(:,FiberPort(rt(1),rt(2)),wave_no,rt(1)) i.e OXC(wave_no) at  source node

%%% Remove the Input Port at Source Node %%%%%%%%%

oxc_sw_stat(:,:,wave_no,rt(1)); % This is the OXC switch status matrix corresponding to the source node and given wavelength number
FiberPort(rt(1),rt(2)); % This is the output port for the source node, what we need is to identify the port at the input where it was added.
%% This loop find the input port where the channel was added
for i=1:np_sd
    if oxc_sw_stat(i,FiberPort(rt(1),rt(2)),wave_no,rt(1))==1 % At the source node remove the first available input port.
        add_ports(wave_no,i,rt(1))=0;
       break
    end
end
% i; % This is the input port number of the OXC(wave_no) at rt(1); That is channel is added
oxc_sw_stat(i,FiberPort(rt(1),rt(2)),wave_no,rt(1))=0; % The removing the connection in the OXC at the source the node after finding the input 
                                                       % port where it was added
oxc_sw_pwr(i,FiberPort(rt(1),rt(2)),wave_no,rt(1))=0;    % Removing the powers that LP has at the source node                               
%%%%%%%%%%%%%%%%%%%%%%%%%%% Intermediate node %%%%%%%%%%%%%%%%%%%%%%
if length(rt)>2
   for j=2:length(rt)-1 % Until the node before to the destination node
       oxc_sw_stat(FiberPort(rt(j-1),rt(j)),FiberPort(rt(j),rt(j+1)),wave_no,rt(j))=0;
       oxc_sw_pwr(FiberPort(rt(j-1),rt(j)),FiberPort(rt(j),rt(j+1)),wave_no,rt(j))=0;
   end
  % j+1; % =length(rt)
else
    j=1; % When the LP is a single hop than the next-hop node is the destination
end
%%%%%%%%%%%%%%%%%%%%% Removing Output Port at Destination Node %%%%%%%%%%%%%%%%%%%%
for k=1:np_sd
    if oxc_sw_stat(FiberPort(rt(j),rt(j+1)),k,wave_no,rt(j+1))==1 % At the destination node remove the first available output port.
       drop_ports(wave_no,k,rt(j+1))=0;
       break
    end
end
% k;
oxc_sw_stat(FiberPort(rt(j),rt(j+1)),k,wave_no,rt(j+1))=0;
oxc_sw_pwr(FiberPort(rt(j),rt(j+1)),k,wave_no,rt(j+1))=0;


