function path = dijkstra(s, d,Topo_No,RT_METHOD)
% path: the list of nodes in the path from source to destination;
% totalCost: the total cost of the path;
% farthestNode: the farthest node to reach for each node after performing
% the routing;
% n: the number of nodes in the network;
% s: source node index;
% d: destination node index;


switch RT_METHOD
    case 1,
        netCostMatrix=phy_topology(Topo_No);  % For Minimum Distance Routing
    case 2,
         netCostMatrix=hop_mat(Topo_No); % For Minimum Hop Routing
end

sz=size(netCostMatrix);
n=sz(1,1);
for i1=1:n
    for i2=1:n
        if netCostMatrix(i1,i2)==0
            netCostMatrix(i1,i2)=inf;
        else 
        end
    end
end

farthestPreviousHop(1:n)=0;    
farthestNextHop(1:n)=0;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i = 1:n
    % initialize the farthest node to be itself;
    farthestPreviousHop(i) = i;     % used to compute the RTS/CTS range;
    farthestNextHop(i) = i;
end;
% all the nodes are un-visited;
visited(1:n) = 0;

distance(1:n) = inf;    % it stores the shortest distance between each node and the source node;
parent(1:n) = 0;

distance(s) = 0;
for i = 1:(n-1),
    temp = [];
    for h = 1:n,
         if visited(h) == 0   % in the tree;
             temp=[temp distance(h)];
         else
             temp=[temp inf];
         end
     end;
     [t, u] = min(temp);    % it starts from node with the shortest distance to the source;
     visited(u) = 1;       % mark it as visited;
     for v = 1:n,           % for each neighbors of node u;
         if ( ( netCostMatrix(u, v) + distance(u)) < distance(v) )
             distance(v) = distance(u) + netCostMatrix(u, v);   % update the shortest distance when a shorter path is found;
             parent(v) = u;                                     % update its parent;
         end;             
     end;
end;

path = [];
if parent(d) ~= 0   % if there is a path!
    t = d;
    path = [d];
    while t ~= s
        p = parent(t);
        path = [p path];
        
        if netCostMatrix(t, farthestPreviousHop(t)) < netCostMatrix(t, p)
            farthestPreviousHop(t) = p;
        end;
        if netCostMatrix(p, farthestNextHop(p)) < netCostMatrix(p, t)
            farthestNextHop(p) = t;
        end;

        t = p;      
    end;
end;

%totalCost = distance(d);

% DisBwNds=zeros(1,length(path)-1); % Distance between the nodes 
% DisBwNds(1)=netCostMatrix(path(1),path(2));
% for i=2:length(path)-1
%     DisBwNds(i)=netCostMatrix(path(i),path(i+1));
% end
return;