function HopMat=hop_mat(Topo_No)
%[DisMat,number_of_links,nds]=phy_topology(Topo_No)
% Case 1: 4 x 4 Mesh torus 
% Case 2: 3 x 3 Mesh Torus
% Case 3: 10 node Ring
% Case 4: NSF Network, 14 nodes and 21 bi-directional links
% Case 5: Italian Mesh Network 21 nodes 36 bi-directional
% Case 6: 24 Node Mesh Network
% Case 7: 11 Node Ring Network
% Case 8: 6 Node Mesh Network (For weights Ref: JOCN, Vol.1, No.1, 2009, pp.176)
% Case 9: Scaled NSF network
% Case 10: Scaled 24 node mesh network
% This function gives the hope matrix for the network topology.
switch Topo_No
    case 1, % Generating 4 x 4 Mesh Torus Topology
        Node_no=16; % Number of Nodes in the 4 x 4 Mesh Torus Network is 16
        HopMat=zeros(Node_no);
        n=sqrt(Node_no);
        for i=1:n:Node_no
            for j=0:n-2
                HopMat(i+j,i+j+1)=1;
                HopMat(i+j+1,i+j)=1;
            end
            HopMat(i+j+1,i)=1; % In these two line j can be replaced with n-1, both are same
            HopMat(i,i+j+1)=1;
        end
        for i=1:n
            for j=0:n:Node_no-n-1
                HopMat(i+j,i+j+n)=1;
                HopMat(i+j+n,i+j)=1;
            end
            j=n*(n-1);
            HopMat(i,i+j)=1;
            HopMat(i+j,i)=1;
        end
   case 2, % Generats 3 x 3 Mesh Torus Topology
        Node_no=9; % Number of Nodes in the 3 x 3 Mesh Torus Network is 9
        HopMat=zeros(Node_no);
        n=sqrt(Node_no);
        for i=1:n:Node_no
            for j=0:n-2
                HopMat(i+j,i+j+1)=1;
                HopMat(i+j+1,i+j)=1;
            end
            HopMat(i+j+1,i)=1; % In these two line j can be replaced with n-1, both are same
            HopMat(i,i+j+1)=1;
        end
        for i=1:n
            for j=0:n:Node_no-n-1
                HopMat(i+j,i+j+n)=1;
                HopMat(i+j+n,i+j)=1;
            end
            j=n*(n-1);
            HopMat(i,i+j)=1;
            HopMat(i+j,i)=1;
        end
  case 3, % Generate 4 node ring
        Node_no=10;
        HopMat=zeros(Node_no);
        for i=1:Node_no-1
            HopMat(i,i+1)=1;
            HopMat(i+1,i)=1;
        end
        HopMat(Node_no,1)=1;
        HopMat(1,Node_no)=1; 
        
    case 4, % Generates NSFNET 14 nodes and 21 bi-directional links
        HopMat=zeros(14);
        HopMat(1,2)=1; HopMat(2,1)=1;
        HopMat(1,3)=1;HopMat(3,1)=1;
        HopMat(1,8)=1;HopMat(8,1)=1;
        HopMat(2,4)=1;HopMat(4,2)=1;
        HopMat(2,3)=1;HopMat(3,2)=1;
        HopMat(3,6)=1;HopMat(6,3)=1;
        HopMat(4,5)=1;HopMat(5,4)=1;
        HopMat(4,11)=1;HopMat(11,4)=1;
        HopMat(5,6)=1;HopMat(6,5)=1;
        HopMat(5,7)=1;HopMat(7,5)=1;
        HopMat(6,13)=1;HopMat(13,6)=1;
        HopMat(6,10)=1;HopMat(10,6)=1;
        HopMat(7,8)=1;HopMat(8,7)=1;
        HopMat(8,9)=1;HopMat(9,8)=1;
        HopMat(9,10)=1;HopMat(10,9)=1;
        HopMat(9,12)=1;HopMat(12,9)=1;
        HopMat(9,14)=1;HopMat(14,9)=1;
        HopMat(11,12)=1;HopMat(12,11)=1;
        HopMat(11,14)=1;HopMat(14,11)=1;
        HopMat(12,13)=1;HopMat(13,12)=1;
        HopMat(13,14)=1;HopMat(14,13)=1;
case 5, % Generates Italian Mesh Network 21 nodes, 36 bi-directional links
        HopMat=zeros(21);
        HopMat(1,2)=1;HopMat(2,1)=1;
        HopMat(1,3)=1;HopMat(3,1)=1;
        HopMat(1,5)=1;HopMat(5,1)=1;
        HopMat(2,3)=1;HopMat(3,2)=1;
        HopMat(2,6)=1;HopMat(6,2)=1;
        HopMat(2,7)=1;HopMat(7,2)=1;
        HopMat(3,4)=1;HopMat(4,3)=1;
        HopMat(3,8)=1;HopMat(8,3)=1;
        HopMat(4,5)=1;HopMat(5,4)=1;
        HopMat(4,8)=1;HopMat(8,4)=1;
        HopMat(6,7)=1;HopMat(7,6)=1;
        HopMat(7,8)=1;HopMat(8,7)=1;
        HopMat(7,9)=1;HopMat(9,7)=1;
        HopMat(7,10)=1;HopMat(10,7)=1;
        HopMat(8,11)=1;HopMat(11,8)=1;
        HopMat(8,10)=1;HopMat(10,8)=1;
        HopMat(9,10)=1;HopMat(10,9)=1;
        HopMat(9,13)=1;HopMat(13,9)=1;
        HopMat(10,12)=1;HopMat(12,10)=1;
        HopMat(10,13)=1;HopMat(13,10)=1;
        HopMat(11,14)=1;HopMat(14,11)=1;
        HopMat(12,13)=1;HopMat(13,12)=1;
        HopMat(12,14)=1;HopMat(14,12)=1;
        HopMat(13,15)=1;HopMat(15,13)=1;
        HopMat(13,16)=1;HopMat(16,13)=1;
        HopMat(14,16)=1;HopMat(16,14)=1;
        HopMat(14,17)=1;HopMat(17,14)=1; % This link was missing the JON paper. It has to be fixed.
        HopMat(15,19)=1;HopMat(19,15)=1;
        HopMat(16,17)=1;HopMat(17,16)=1;
        HopMat(16,18)=1;HopMat(18,16)=1;
        HopMat(16,19)=1;HopMat(19,16)=1;
        HopMat(16,20)=1;HopMat(20,16)=1;
        HopMat(17,18)=1;HopMat(18,17)=1;
        HopMat(18,21)=1;HopMat(21,18)=1;
        HopMat(19,20)=1;HopMat(20,19)=1;
        HopMat(20,21)=1;HopMat(21,20)=1;
        %
case 6, % Generates a 24 node Mesh Topology given in the JSAC Vol.22,No.9
        HopMat=zeros(24);
        HopMat(1,2)=1;HopMat(2,1)=1;
        HopMat(1,6)=1;HopMat(6,1)=1;
        HopMat(2,3)=1;HopMat(3,2)=1;
        HopMat(2,6)=1;HopMat(6,2)=1;
        HopMat(3,4)=1;HopMat(4,3)=1;
        HopMat(3,5)=1;HopMat(5,3)=1;
        HopMat(3,7)=1;HopMat(7,3)=1;
        HopMat(4,5)=1;HopMat(5,4)=1;
        HopMat(4,7)=1;HopMat(7,4)=1;
        HopMat(5,8)=1;HopMat(8,5)=1;
        HopMat(6,7)=1;HopMat(7,6)=1;
        HopMat(6,9)=1;HopMat(9,6)=1;
        HopMat(6,11)=1;HopMat(11,6)=1;
        HopMat(7,9)=1;HopMat(9,7)=1;
        HopMat(7,8)=1;HopMat(8,7)=1;
        HopMat(8,10)=1;HopMat(10,8)=1;
        HopMat(9,10)=1;HopMat(10,9)=1;
        HopMat(9,11)=1;HopMat(11,9)=1;
        HopMat(9,12)=1;HopMat(12,9)=1;
        HopMat(10,13)=1;HopMat(13,10)=1;
        HopMat(10,14)=1;HopMat(14,10)=1;
        HopMat(11,12)=1;HopMat(12,11)=1;
        HopMat(11,15)=1;HopMat(15,11)=1;
        HopMat(12,13)=1;HopMat(13,12)=1;
        HopMat(12,16)=1;HopMat(16,12)=1;
        HopMat(13,14)=1;HopMat(14,13)=1;
        HopMat(13,17)=1;HopMat(17,13)=1;
        HopMat(14,18)=1;HopMat(18,14)=1;
        HopMat(15,16)=1;HopMat(16,15)=1;
        HopMat(15,19)=1;HopMat(19,15)=1;
        HopMat(15,20)=1;HopMat(20,15)=1;
        HopMat(16,17)=1;HopMat(17,16)=1;
        HopMat(16,21)=1;HopMat(21,16)=1;
        HopMat(16,22)=1;HopMat(22,16)=1;
        HopMat(17,18)=1;HopMat(18,17)=1;
        HopMat(17,22)=1;HopMat(22,17)=1;
        HopMat(17,23)=1;HopMat(23,17)=1;
        HopMat(18,24)=1;HopMat(24,18)=1;
        HopMat(19,20)=1;HopMat(20,19)=1;
        HopMat(20,21)=1;HopMat(21,20)=1;
        HopMat(21,22)=1;HopMat(22,21)=1;
        HopMat(22,23)=1;HopMat(23,22)=1;
        HopMat(23,24)=1;HopMat(24,23)=1;
        
   case 7, % Generate 11 node ring
        Node_no=11;
        HopMat=zeros(Node_no);
        for i=1:Node_no-1
            HopMat(i,i+1)=1;
            HopMat(i+1,i)=1;
        end
        HopMat(Node_no,1)=1;
        HopMat(1,Node_no)=1; 
       
        
   case 8, % Generate 6 node mesh topology
        Node_no=6;
        HopMat=zeros(Node_no);
        HopMat(1,2)=1;
        HopMat(1,3)=1;
        HopMat(2,3)=1;
        HopMat(2,4)=1;
        HopMat(3,5)=1;
        HopMat(4,5)=1;
        HopMat(4,6)=1;
        HopMat(5,6)=1;
        HopMat=HopMat+transpose(HopMat);
    case 9, % Generates Scaled NSFNET (Same as Case 4) 14 nodes and 21 bi-directional links
        HopMat=zeros(14);
        HopMat(1,2)=1; HopMat(2,1)=1;
        HopMat(1,3)=1;HopMat(3,1)=1;
        HopMat(1,8)=1;HopMat(8,1)=1;
        HopMat(2,4)=1;HopMat(4,2)=1;
        HopMat(2,3)=1;HopMat(3,2)=1;
        HopMat(3,6)=1;HopMat(6,3)=1;
        HopMat(4,5)=1;HopMat(5,4)=1;
        HopMat(4,11)=1;HopMat(11,4)=1;
        HopMat(5,6)=1;HopMat(6,5)=1;
        HopMat(5,7)=1;HopMat(7,5)=1;
        HopMat(6,13)=1;HopMat(13,6)=1;
        HopMat(6,10)=1;HopMat(10,6)=1;
        HopMat(7,8)=1;HopMat(8,7)=1;
        HopMat(8,9)=1;HopMat(9,8)=1;
        HopMat(9,10)=1;HopMat(10,9)=1;
        HopMat(9,12)=1;HopMat(12,9)=1;
        HopMat(9,14)=1;HopMat(14,9)=1;
        HopMat(11,12)=1;HopMat(12,11)=1;
        HopMat(11,14)=1;HopMat(14,11)=1;
        HopMat(12,13)=1;HopMat(13,12)=1;
        HopMat(13,14)=1;HopMat(14,13)=1;
    case 10, % Generates a Scaled 24 node Mesh Topology (same as case 6)given in the JSAC Vol.22,No.9
        HopMat=zeros(24);
        HopMat(1,2)=1;HopMat(2,1)=1;
        HopMat(1,6)=1;HopMat(6,1)=1;
        HopMat(2,3)=1;HopMat(3,2)=1;
        HopMat(2,6)=1;HopMat(6,2)=1;
        HopMat(3,4)=1;HopMat(4,3)=1;
        HopMat(3,5)=1;HopMat(5,3)=1;
        HopMat(3,7)=1;HopMat(7,3)=1;
        HopMat(4,5)=1;HopMat(5,4)=1;
        HopMat(4,7)=1;HopMat(7,4)=1;
        HopMat(5,8)=1;HopMat(8,5)=1;
        HopMat(6,7)=1;HopMat(7,6)=1;
        HopMat(6,9)=1;HopMat(9,6)=1;
        HopMat(6,11)=1;HopMat(11,6)=1;
        HopMat(7,9)=1;HopMat(9,7)=1;
        HopMat(7,8)=1;HopMat(8,7)=1;
        HopMat(8,10)=1;HopMat(10,8)=1;
        HopMat(9,10)=1;HopMat(10,9)=1;
        HopMat(9,11)=1;HopMat(11,9)=1;
        HopMat(9,12)=1;HopMat(12,9)=1;
        HopMat(10,13)=1;HopMat(13,10)=1;
        HopMat(10,14)=1;HopMat(14,10)=1;
        HopMat(11,12)=1;HopMat(12,11)=1;
        HopMat(11,15)=1;HopMat(15,11)=1;
        HopMat(12,13)=1;HopMat(13,12)=1;
        HopMat(12,16)=1;HopMat(16,12)=1;
        HopMat(13,14)=1;HopMat(14,13)=1;
        HopMat(13,17)=1;HopMat(17,13)=1;
        HopMat(14,18)=1;HopMat(18,14)=1;
        HopMat(15,16)=1;HopMat(16,15)=1;
        HopMat(15,19)=1;HopMat(19,15)=1;
        HopMat(15,20)=1;HopMat(20,15)=1;
        HopMat(16,17)=1;HopMat(17,16)=1;
        HopMat(16,21)=1;HopMat(21,16)=1;
        HopMat(16,22)=1;HopMat(22,16)=1;
        HopMat(17,18)=1;HopMat(18,17)=1;
        HopMat(17,22)=1;HopMat(22,17)=1;
        HopMat(17,23)=1;HopMat(23,17)=1;
        HopMat(18,24)=1;HopMat(24,18)=1;
        HopMat(19,20)=1;HopMat(20,19)=1;
        HopMat(20,21)=1;HopMat(21,20)=1;
        HopMat(21,22)=1;HopMat(22,21)=1;
        HopMat(22,23)=1;HopMat(23,22)=1;
        HopMat(23,24)=1;HopMat(24,23)=1;
end