clc
clear
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This is just to print the details to the output file 
% input=fopen('InputParam.txt','r'); % Opens the input file
% InputData=fscanf(input,'%f',[1,inf]); % Reads the input file and creates a row matrix for the input data.
load('InputParam.txt','-ascii'); % Loads the values in the InputParam.txt and assigns a variable InputParam
% Remember to write the input data in a row matrix form
% Input Data should be of the order: 1) Number of Requests
%                                    2) Topology Number
%                                    3) Number of Wavelengths
%                                    4) Q-factor threshold
%                                    5) Routing Method
%                                    6) Lower limit (Network Load)
%                                    7) Increment Network Load
%                                    8) Upper limit Network Load
%                                    9) Probable number of destinations (set D_s)
%                                   10) Wavelength Assignment Method (Random -1, First Fit -2)
%                                   11) Latency Threshold (tau_LP+tau_pd <=tau_th)
num_of_requests=InputParam(1); % The more the number of requests, the time-avgs converges to steady-state avgs (analytical)
%%% This is Addeded here to make it work for different routing algorithms %%%% %%%% 
Topo_No=InputParam(2); 
[DisMat, number_of_links,nds,num_of_wavelengths,q_th,max_degree,RT_METHOD,num_of_des,wave_assginment,tau_th]=constants(Topo_No);

FiberPort=crosstalk(Topo_No); % This matrix gives the mapping between ports in the OXC to the fiber. 
                              % This is a constant matrix for the given network and the size of the OXC
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if Topo_No==11
    MAX_NDS=20; % This is for only for CORONET
else 
    NO_NODES=zeros(nds); % This matrix gives the number of nodes of a path, for all source and destinations
    % Example : Route= 1->2->3 then NO_NODES(1,3)=3 means that the request with
    % source=1, des=3 used three nodes (including the source and destination)
    for i=1:nds
        for j=1:nds
            if i~=j
               Route=dijkstra(i,j,Topo_No,RT_METHOD);
               NO_NODES(i,j)=length(Route);
            end
        end
    end
    MAX_NDS=max(max(NO_NODES)); %This is the max number of nodes a route can have between any source and destination pair
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
mkdir output; % Creates a folder in the working directory and collects all the results
output=fopen('output/result.txt','w');
logfile=fopen('output/log.txt','w'); % Creates a log file, that keeps track of each request. 
loss_probability=fopen('output/loss.txt','w');
latencyfile=fopen('output/latencyLP.txt','w');
time=fopen('output/exe_time.txt','w'); % Keeps track of Execution time 
fprintf(output,'~~~~~~~~~~~~~~~ Anycast Simulations ~~~~~~~~~~~~~~~~~~ \n');
switch RT_METHOD
    case 1,
         fprintf(output,' These results are based on the Minimum-Distance \n');
    case 2,
         fprintf(output,' These results are based on the Minimum-Hop \n');   
end
switch wave_assginment
    case 1
        fprintf(output, ' Wavelength Assignment: Random \n');
    case 2
        fprintf(output, ' Wavelength Assignment: First Fit \n');
end
fprintf(output, ' Number of Requests: %d \n', num_of_requests);
switch Topo_No
    case 1, % Generating 4 x 4 Mesh Torus Topology
        fprintf(output, ' Topology used for Simulation is 4x4 Mesh Network \n');
    case 2, % Generats 3 x 3 Mesh Torus Topology
       fprintf(output,  ' Topology used for Simulation is 3x3 Mesh Network \n');
    case 3, % Generate 4 node ring
        fprintf(output, ' Topology used for Simulation is 10 Node Ring Network \n');
    case 4, % Generates NSFNET 14 nodes and 21 bi-directional links
       fprintf(output, ' Topology used for Simulation is NSF Network \n');
    case 5, % Generates Italian Mesh Network 21 nodes, 36 bi-directional links
        fprintf(output, ' Topology used for Simulation is Italian Mesh Network \n');
    case 6, % Generates a 24 node Mesh Topology given in the JSAC Vol.22,No.9
       fprintf(output, ' Topology used for Simulation is 24 node Mesh Network \n');
    case 7, % Generate 11 node ring
       fprintf(output, ' Topology used for Simulation is 11 node ring Network \n');
    case 8, % Generate 6 node mesh topology
       fprintf(output, ' Topology used for Simulation is 6 node mesh network \n');
    case 9, % Generate a Scaled NSF topology
       fprintf(output, ' Topology used for Simulation is Scaled-NSF mesh network \n');
    case 10, % Generate a Scaled 24 node mesh topology
      fprintf(output, ' Topology used for Simulation is Scaled-24 node mesh network \n');
    case 11, % Generate a Scaled 24 node mesh topology
      fprintf(output, ' Topology used for Simulation is CORONET \n');
end
fprintf(output, ' Number of Wavelengths: %d \n', num_of_wavelengths);
fprintf(output, ' Anycast Configuration used is %d-1',num_of_des);
fprintf(output, '\n ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ \n');
%%%%%%%%%%%%%%%%%%%%%%%%%%% CONSTANTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[N,np_sd,Be,Bo,tx_pw,L_mx,L_dm,L_s,L_w,L_sw,L_tap,l,L,Xsw,Gin_max,Gout_max,G_dB,lambda_array,nsp,h,alpha,bit_rate,wave_spcg]= ...
parameters(max_degree,num_of_wavelengths);
    const=fopen('output/swt_const.txt','w');
    fprintf(const,'The Parameters Used in the Estimation of BER \n');
    fprintf(const, '**********************************\n');
    fprintf(const, 'The Bit-Rate of the Channel: %3.2e \n',bit_rate);
    fprintf(const, 'The Electrical Bandwidth: %3.2e \n',Be);  
    fprintf(const, 'The Optical Bandwidth: %3.2e\n',Bo);  
    fprintf(const, 'Threshold for the q-factor: %3.1f \n',q_th); % q_th comes from constants.m
    fprintf(const, 'Threshold for the latency (in ms): %3.2f \n',tau_th); % tau_th comes from constants.m
    fprintf(const, 'Input Signal Power at the transmitter (dBm): %3.1f\n',tx_pw);  
    fprintf(const, 'Multiplexer Loss (dB): %2.1f\n',L_mx);  
    fprintf(const, 'Demultiplexer Loss (dB): %2.1f\n',L_dm); 
    fprintf(const, 'Switch Element insertion Loss (dB): %2.1f\n',L_s); 
    fprintf(const, 'Waveguide to Fiber Coupling Loss (dB): %2.1f\n',L_w);
    fprintf(const, 'Switch Loss for %d*%d Swtich (dB): %2.1f\n',N,N,L_sw);
    fprintf(const, 'Number of I/O ports that can be used for add/drop by any OXC in the network: %2d\n',np_sd);
    fprintf(const, 'Tap Loss (dB): %2.1f\n',L_tap);
    fprintf(const, 'Amplifier Spacing: %d\n',l);
    fprintf(const, 'Attenuation (dB/km): %2.1f\n',L);
    fprintf(const, 'Attenuation (/km): %2.4f\n',alpha);
    fprintf(const, 'Switch Crosstalk Ratio (dB): %2.1f\n',-10*log10(Xsw));
    fprintf(const, 'Input Preamplifier Gain (dB): %2.1f\n',Gin_max);    
    fprintf(const, 'Output Preamplifier Gain (dB): %2.1f\n',Gout_max);
    fprintf(const, 'Inline Amplifer Gain (dB): %2.1f\n',G_dB);
    fprintf(const, 'Amplified Spontaneous Emission Noise: %2.1f\n',nsp);
    fprintf(const, 'Plank''s Constant (J-s or J/Hz): %3.2e\n',h);
    fprintf(const, 'Wavelength Spacing (nm): %3.2e\n',wave_spcg/1e-9);
    fprintf(const, 'Wavelength Array (nm):');
    fprintf(const, '  %7.1f',lambda_array./1e-9);
    fprintf(const, '\n');
    fclose(const);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
temp=0;
%global inital_latency;
% lambda=10;
for lambda=InputParam(6):InputParam(7):InputParam(8) % Here lambda is the arrival rate not the wavelengths
    tic % Tic is used to start the timer for each load. 
    mean_interarrival=1/lambda; % Mean time between the arrivals % This is 1/lambda where lambda is the arrival rate
    mean_service=1; % This is mean service time time which is 1/mu where is the service rate 
    num_events=2; % Number of events (i.e depature and arrival)
    temp=temp+1; % Used for blocking probability array
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% Initlization of the Simulation %%
    sim_time=0;
    % Intialization of State variables
    %server_sta=0; % 0=Server is idle; 1=server is busy
    % Defining the values for 'IDLE'  and 'BUSY'
    %time_last_event=0;
    time_next_event(1)=0; % This is the value that maintains the time of the next event to occur for arrival
    time_next_event(2)=Inf; % This is the value that maintains the time of the next event to occur for departure
    num_call_dropped=0; % As there is no buffer in optical networks calls are dropped if the channel is not free
    num_call_dropped_q=0; % This indicates the number of calls that does not satisfy the NF or the delay condition of the network
    num_call_dropped_delay=0;  % This indicates the number of calls that does not satisfy the latency constraint
    num_of_arrivals=0; % This used to check the number of arrivals and used as the condition to terminate the program
    tau_total=0; % Total LP provisioning delay for all the requests (including the time for unsuccessful).
    LinkStatusMat=zeros(nds); % Intialization for the Link Status of the topology. 1=USED; 0=UNUSED;
    %%% Added for XT %
    N=2^(ceil(log2(2*max_degree))); % Switch size N x N
    np_sd=N-max_degree; % Number of ports used for add(i.e., source: 's') and drop (i.e., destination: 'd')
    oxc_sw_stat=zeros(N,N,num_of_wavelengths,nds); % oxc_sw_stat(:,:,wave_no,node_num) indicates the used (=1) and unused ports(=0) 
    oxc_sw_pwr=zeros(N,N,num_of_wavelengths,nds); % Indicates the power values (in mW) between input and output ports
    add_ports=zeros(num_of_wavelengths,np_sd,nds); % Indicates the number of channels added (acting as the source) for a given wavelength 
    %and node number
    drop_ports=zeros(num_of_wavelengths,np_sd,nds); % Indicates the number of channels added (acting as the source) for a given wavelength 
    %and node number
    LOG_MAT=zeros(1,MAX_NDS+2+1+1); 
        % This matrix maintains the log of each  successful request. The additional 2 columns are for arrival time and departure time.
    % Example: LOG_MAT(1,1) is REQ_ID, LOG_MAT(1,2)....LOG_MAT(1,MAX_NDS+1) is the route informations. 
    % LOG_MAT(1,MAX_NDS+2) and LOG_MAT(1,MAX_NDS+3) are arrival and departure respectively.
    % LOG_MAT(1,MAX_NDS+4) is the wavelength number that is assigned.

    %%% Code added for multiple wavelengths %%%%%
    for i=1:num_of_wavelengths
        LinkStatusMat(:,:,i)=zeros(nds); % Each wavelength is used as the dimension of the matrix: 
                                         % Example LinkStatusMat(1,3,4) represents the link status between node 1 and 3 on a wavelength 4
    end
    DeptMat=zeros(nds,nds,num_of_wavelengths,2); % This matrix gives the departure time of each call.
    % It is a four dimensional matrix with (i,j,k,l) where i is the source  node number, j=destination node number, k=is the wavelength nnumber,
    % l is a 2-d array with 1st element representing the departure time and  the next element represents the REQ_ID.
    % Example DeptMat(1,2,3,1)=34.7 denotes the LP between nodes 1->3 on wavelength 3 departs at 34.7 and DeptMat(1,2,3,2)=1498 is the request 
    % ID for that LP
    for i=1:nds
      for j=1:nds
        for k=1:num_of_wavelengths
            DeptMat(i,j,k,1)=Inf; 
        end
     end
   end
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    while(num_of_arrivals<=num_of_requests-1) % We have subtracted 1 from the number of requests, 
                                               % since the while condition runs for num_of_requests +1 i.e, 
                                               %  including the case when num_of_arrivals=0
        
         [sim_time,next_event_type,time_next_event]=timing(time_next_event,num_events);
         switch next_event_type
            case 1 
                REQ_ID=num_of_arrivals+1;
                %% When there is an arrival assign the source-destination pair to the arrival.
                
                [time_next_event, num_call_dropped,num_call_dropped_q, num_call_dropped_delay,sim_time, LinkStatusMat,DeptMat,oxc_sw_stat, ...
                oxc_sw_pwr,add_ports,drop_ports,LOG_MAT,tau_total]=arrive(time_next_event,sim_time, mean_interarrival,mean_service,...
                num_call_dropped,num_call_dropped_q, num_call_dropped_delay, Topo_No,LinkStatusMat,DeptMat,oxc_sw_stat,oxc_sw_pwr,add_ports, ...
                drop_ports,FiberPort,LOG_MAT,REQ_ID,MAX_NDS,tau_total);
                                                                   
                num_of_arrivals=num_of_arrivals+1;
                
            case 2 
                [time_next_event,LinkStatusMat,DeptMat,oxc_sw_stat,oxc_sw_pwr,add_ports,drop_ports,LOG_MAT]=depart(time_next_event,...
                 LinkStatusMat,DeptMat,Topo_No,oxc_sw_stat,oxc_sw_pwr,add_ports,drop_ports,FiberPort,...
                 RT_METHOD,LOG_MAT,MAX_NDS);
         end
    end
    avg_req_lost=num_call_dropped/num_of_requests;
    avg_latency_LP=tau_total/(num_of_requests-num_call_dropped);
    blocking(temp)=avg_req_lost;
    fprintf(loss_probability,'%e\n',blocking(temp) );
    algo_time=toc;
    fprintf(time,'%f\n',algo_time/(60*60)); % toc records the elapsed time for each network load in hours
    fprintf(latencyfile, '%f\n',avg_latency_LP);
    fprintf(output, ' \n Network Load (Erlangs): %.2f \n', lambda*mean_service);
    fprintf(output, ' \n Average Blocking Probability: %5.4e\n', avg_req_lost);
    % fprintf(output, ' \n Average Connection Provisioning Latency (in ms): %5.4e\n', avg_latency_LP);
    fprintf(output, ' \n Calls lost due to Q-factor Threshold: %d \n', num_call_dropped_q);
    fprintf(output, ' \n Calls lost due to Latency Threshold: %d \n', num_call_dropped_delay);
    fprintf(output, ' \n Calls lost due to Wavelength Unavailability: %d \n', num_call_dropped-num_call_dropped_q-num_call_dropped_delay);
    fprintf(output, ' \n ****************************** \n');
    fprintf(logfile, 'Simulation for load %.2f ended at %.2f \n',lambda*mean_service,sim_time);
    fprintf(logfile, ' \n ******************************************************** \n');
end
fclose(loss_probability);
fclose(output);
fclose(logfile);
fclose(time);
%exit;
