function [DisMat,number_of_links,nds,max_degree]=phy_topology(Topo_No)
%[DisMat,number_of_links,nds]=phy_topology(Topo_No)
% Case 1: 4 x 4 Mesh torus 
% Case 2: 3 x 3 Mesh Torus
% Case 3: 10 node Ring
% Case 4: NSF Network, 14 nodes and 21 bi-directional links
% Case 5: Italian Mesh Network 21 nodes 36 bi-directional
% Case 6: 24 Node Mesh Network
% Case 7: 11 Node Ring Network
% Case 8: 6 Node Mesh Network (For weights Ref: JOCN, Vol.1, No.1, 2009, pp.176)
% Case 9: Scaled NSF network
% Case 10: Scaled 24 node mesh network
% Case 11: CONUS CORNET Mesh network
number_of_links=0;
switch Topo_No
    case 1, % Generating 4 x 4 Mesh Torus Topology
        Node_no=16; % Number of Nodes in the 4 x 4 Mesh Torus Network is 16
        DisMat=zeros(Node_no);
        n=sqrt(Node_no);
        for i=1:n:Node_no
            for j=0:n-2
                DisMat(i+j,i+j+1)=1;
                DisMat(i+j+1,i+j)=1;
            end
            DisMat(i+j+1,i)=1; % In these two line j can be replaced with n-1, both are same
            DisMat(i,i+j+1)=1;
        end
        for i=1:n
            for j=0:n:Node_no-n-1
                DisMat(i+j,i+j+n)=1;
                DisMat(i+j+n,i+j)=1;
            end
            j=n*(n-1);
            DisMat(i,i+j)=1;
            DisMat(i+j,i)=1;
        end
        DisMat=70*DisMat;
        %
        max_degree=0;
        for i=1:length(DisMat)
            degree=0;
            for j=1:length(DisMat)
              if DisMat(i,j)>0
                 number_of_links=number_of_links+1;
                 degree=degree+1;
              end
            end
            max_degree=max(degree,max_degree);
        end
        nds=Node_no; % Number of nodes in the network
        
    case 2, % Generats 3 x 3 Mesh Torus Topology
        Node_no=9; % Number of Nodes in the 3 x 3 Mesh Torus Network is 9
        DisMat=zeros(Node_no);
        n=sqrt(Node_no);
        for i=1:n:Node_no
            for j=0:n-2
                DisMat(i+j,i+j+1)=1;
                DisMat(i+j+1,i+j)=1;
            end
            DisMat(i+j+1,i)=1; % In these two line j can be replaced with n-1, both are same
            DisMat(i,i+j+1)=1;
        end
        for i=1:n
            for j=0:n:Node_no-n-1
                DisMat(i+j,i+j+n)=1;
                DisMat(i+j+n,i+j)=1;
            end
            j=n*(n-1);
            DisMat(i,i+j)=1;
            DisMat(i+j,i)=1;
        end
        DisMat=70*DisMat;
        %
        max_degree=0;
        for i=1:length(DisMat)
            degree=0;
            for j=1:length(DisMat)
              if DisMat(i,j)>0
                 number_of_links=number_of_links+1;
                 degree=degree+1;
              end
            end
            max_degree=max(degree,max_degree);
        end
        nds=Node_no;
    case 3, % Generate 4 node ring
        Node_no=10;
        DisMat=zeros(Node_no);
        for i=1:Node_no-1
            DisMat(i,i+1)=1;
            DisMat(i+1,i)=1;
        end
        DisMat(Node_no,1)=1;
        DisMat(1,Node_no)=1; 
        DisMat=70*DisMat;
        %
        max_degree=0;
        for i=1:length(DisMat)
            degree=0;
            for j=1:length(DisMat)
              if DisMat(i,j)>0
                 number_of_links=number_of_links+1;
                 degree=degree+1;
              end
            end
            max_degree=max(degree,max_degree);
        end
        nds=Node_no;
    case 4, % Generates NSFNET 14 nodes and 21 bi-directional links
        DisMat=zeros(14);
        DisMat(1,2)=1100; DisMat(2,1)=1100;
        DisMat(1,3)=1600;DisMat(3,1)=1600;
        DisMat(1,8)=2800;DisMat(8,1)=2800;
        DisMat(2,4)=1000;DisMat(4,2)=1000;
        DisMat(2,3)=600;DisMat(3,2)=600;
        DisMat(3,6)=2000;DisMat(6,3)=2000;
        DisMat(4,5)=600;DisMat(5,4)=600;
        DisMat(4,11)=2400;DisMat(11,4)=2400;
        DisMat(5,6)=1100;DisMat(6,5)=1100;
        DisMat(5,7)=800;DisMat(7,5)=800;
        DisMat(6,13)=2000;DisMat(13,6)=2000;
        DisMat(6,10)=1200;DisMat(10,6)=1200;
        DisMat(7,8)=700;DisMat(8,7)=700;
        DisMat(8,9)=700;DisMat(9,8)=700;
        DisMat(9,10)=900;DisMat(10,9)=900;
        DisMat(9,12)=500;DisMat(12,9)=500;
        DisMat(9,14)=500;DisMat(14,9)=500;
        DisMat(11,12)=800;DisMat(12,11)=800;
        DisMat(11,14)=300;DisMat(14,11)=300;
        DisMat(12,13)=300;DisMat(13,12)=300;
        DisMat(13,14)=300;DisMat(14,13)=300;
        %
        max_degree=0;
        for i=1:length(DisMat)
            degree=0;
            for j=1:length(DisMat)
              if DisMat(i,j)>0
                 number_of_links=number_of_links+1;
                 degree=degree+1;
              end
            end
            max_degree=max(degree,max_degree);
        end
        nds=14; % Number of nodes in NSFNET
    case 5, % Generates Italian Mesh Network 21 nodes, 36 bi-directional links
        DisMat=zeros(21);
        DisMat(1,2)=140;DisMat(2,1)=140;
        DisMat(1,3)=110;DisMat(3,1)=110;
        DisMat(1,5)=210;DisMat(5,1)=210;
        DisMat(2,3)=110;DisMat(3,2)=110;
        DisMat(2,6)=95;DisMat(6,2)=95;
        DisMat(2,7)=90;DisMat(7,2)=90;
        DisMat(3,4)=90;DisMat(4,3)=90;
        DisMat(3,8)=95;DisMat(8,3)=95;
        DisMat(4,5)=85;DisMat(5,4)=85;
        DisMat(4,8)=95;DisMat(8,4)=95;
        DisMat(6,7)=90;DisMat(7,6)=90;
        DisMat(7,8)=130;DisMat(8,7)=130;
        DisMat(7,9)=120;DisMat(9,7)=120;
        DisMat(7,10)=150;DisMat(10,7)=150;
        DisMat(8,11)=200;DisMat(11,8)=200;
        DisMat(8,10)=55;DisMat(10,8)=55;
        DisMat(9,10)=60;DisMat(10,9)=60;
        DisMat(9,13)=190;DisMat(13,9)=190;
        DisMat(10,12)=110;DisMat(12,10)=110;
        DisMat(10,13)=180;DisMat(13,10)=180;
        DisMat(11,14)=130;DisMat(14,11)=130;
        DisMat(12,13)=120;DisMat(13,12)=120;
        DisMat(12,14)=170;DisMat(14,12)=170;
        DisMat(13,15)=460;DisMat(15,13)=460;
        DisMat(13,16)=180;DisMat(16,13)=180;
        DisMat(14,16)=200;DisMat(16,14)=200;
        DisMat(14,17)=270;DisMat(17,14)=270; % This link was missing the JON paper. It has to be fixed.
        DisMat(15,19)=420;DisMat(19,15)=420;
        DisMat(16,17)=210;DisMat(17,16)=210;
        DisMat(16,18)=90;DisMat(18,16)=90;
        DisMat(16,19)=310;DisMat(19,16)=310;
        DisMat(16,20)=350;DisMat(20,16)=350;
        DisMat(17,18)=100;DisMat(18,17)=100;
        DisMat(18,21)=200;DisMat(21,18)=200;
        DisMat(19,20)=150;DisMat(20,19)=150;
        DisMat(20,21)=210;DisMat(21,20)=210;
        %
        max_degree=0;
        for i=1:length(DisMat)
            degree=0;
            for j=1:length(DisMat)
              if DisMat(i,j)>0
                 number_of_links=number_of_links+1;
                 degree=degree+1;
              end
            end
            max_degree=max(degree,max_degree);
        end
        nds=21;
    case 6, % Generates a 24 node Mesh Topology given in the JSAC Vol.22,No.9
        DisMat=zeros(24);
        DisMat(1,2)=800;DisMat(2,1)=800;
        DisMat(1,6)=1000;DisMat(6,1)=1000;
        DisMat(2,3)=1100;DisMat(3,2)=1100;
        DisMat(2,6)=950;DisMat(6,2)=950;
        DisMat(3,4)=250;DisMat(4,3)=250;
        DisMat(3,5)=1000;DisMat(5,3)=1000;
        DisMat(3,7)=1000;DisMat(7,3)=1000;
        DisMat(4,5)=800;DisMat(5,4)=800;
        DisMat(4,7)=850;DisMat(7,4)=850;
        DisMat(5,8)=800;DisMat(8,5)=800;
        DisMat(6,7)=1000;DisMat(7,6)=1000;
        DisMat(6,9)=1200;DisMat(9,6)=1200;
        DisMat(6,11)=1900;DisMat(11,6)=1900;
        DisMat(7,9)=1000;DisMat(9,7)=1000;
        DisMat(7,8)=1150;DisMat(8,7)=1150;
        DisMat(8,10)=900;DisMat(10,8)=900;
        DisMat(9,10)=1000;DisMat(10,9)=1000;
        DisMat(9,11)=1400;DisMat(11,9)=1400;
        DisMat(9,12)=1000;DisMat(12,9)=1000;
        DisMat(10,13)=950;DisMat(13,10)=950;
        DisMat(10,14)=850;DisMat(14,10)=850;
        DisMat(11,12)=900;DisMat(12,11)=900;
        DisMat(11,15)=1300;DisMat(15,11)=1300;
        DisMat(12,13)=900;DisMat(13,12)=900;
        DisMat(12,16)=1000;DisMat(16,12)=1000;
        DisMat(13,14)=650;DisMat(14,13)=650;
        DisMat(13,17)=1100;DisMat(17,13)=1100;
        DisMat(14,18)=1200;DisMat(18,14)=1200;
        DisMat(15,16)=600;DisMat(16,15)=600;
        DisMat(15,19)=2600;DisMat(19,15)=2600;
        DisMat(15,20)=1300;DisMat(20,15)=1300;
        DisMat(16,17)=1000;DisMat(17,16)=1000;
        DisMat(16,21)=1000;DisMat(21,16)=1000;
        DisMat(16,22)=800;DisMat(22,16)=800;
        DisMat(17,18)=800;DisMat(18,17)=800;
        DisMat(17,22)=850;DisMat(22,17)=850;
        DisMat(17,23)=1000;DisMat(23,17)=1000;
        DisMat(18,24)=900;DisMat(24,18)=900;
        DisMat(19,20)=1350;DisMat(20,19)=1350; % Orginally in the JSAC paper it is DIS_MAT(19,20)=1200;DIS_MAT(20,19)=1200;
        DisMat(20,21)=700;DisMat(21,20)=700;
        DisMat(21,22)=300;DisMat(22,21)=300;
        DisMat(22,23)=600;DisMat(23,22)=600;
        DisMat(23,24)=900;DisMat(24,23)=900;
        %
        max_degree=0;
        for i=1:length(DisMat)
            degree=0;
            for j=1:length(DisMat)
              if DisMat(i,j)>0
                 number_of_links=number_of_links+1;
                 degree=degree+1;
              end
            end
            max_degree=max(degree,max_degree);
        end
        nds=24;
   case 7, % Generate 11 node ring
        Node_no=11;
        DisMat=zeros(Node_no);
        for i=1:Node_no-1
            DisMat(i,i+1)=1;
            DisMat(i+1,i)=1;
        end
        DisMat(Node_no,1)=1;
        DisMat(1,Node_no)=1; 
        DisMat=70*DisMat;
        %
        max_degree=0;
        for i=1:length(DisMat)
            degree=0;
            for j=1:length(DisMat)
              if DisMat(i,j)>0
                 number_of_links=number_of_links+1;
                 degree=degree+1;
              end
            end
            max_degree=max(degree,max_degree);
        end
        nds=Node_no;
        
   case 8, % Generate 6 node mesh topology
        Node_no=6;
        DisMat=zeros(Node_no);
        DisMat(1,2)=324;
        DisMat(1,3)=368;
        DisMat(2,3)=432;
        DisMat(2,4)=592;
        DisMat(3,5)=632;
        DisMat(4,5)=464;
        DisMat(4,6)=384;
        DisMat(5,6)=336;
        DisMat=DisMat+transpose(DisMat);
        max_degree=0;
        for i=1:length(DisMat)
            degree=0;
            for j=1:length(DisMat)
              if DisMat(i,j)>0
                 number_of_links=number_of_links+1;
                 degree=degree+1;
              end
            end
            max_degree=max(degree,max_degree);
        end
        nds=Node_no;
    case 9, % Generates Scaled NSFNET (distances are decreased by 10 times) 14 nodes and 21 bi-directional links
        DisMat=zeros(14);
        DisMat(1,2)=110; DisMat(2,1)=110;
        DisMat(1,3)=160;DisMat(3,1)=160;
        DisMat(1,8)=280;DisMat(8,1)=280;
        DisMat(2,4)=100;DisMat(4,2)=100;
        DisMat(2,3)=60;DisMat(3,2)=60;
        DisMat(3,6)=200;DisMat(6,3)=200;
        DisMat(4,5)=60;DisMat(5,4)=60;
        DisMat(4,11)=240;DisMat(11,4)=240;
        DisMat(5,6)=110;DisMat(6,5)=110;
        DisMat(5,7)=80;DisMat(7,5)=80;
        DisMat(6,13)=200;DisMat(13,6)=200;
        DisMat(6,10)=120;DisMat(10,6)=120;
        DisMat(7,8)=70;DisMat(8,7)=70;
        DisMat(8,9)=70;DisMat(9,8)=70;
        DisMat(9,10)=90;DisMat(10,9)=90;
        DisMat(9,12)=50;DisMat(12,9)=50;
        DisMat(9,14)=50;DisMat(14,9)=50;
        DisMat(11,12)=80;DisMat(12,11)=80;
        DisMat(11,14)=30;DisMat(14,11)=30;
        DisMat(12,13)=30;DisMat(13,12)=30;
        DisMat(13,14)=30;DisMat(14,13)=30;
        %
        max_degree=0;
        for i=1:length(DisMat)
            degree=0;
            for j=1:length(DisMat)
              if DisMat(i,j)>0
                 number_of_links=number_of_links+1;
                 degree=degree+1;
              end
            end
            max_degree=max(degree,max_degree);
        end
        nds=14; % Number of nodes in NSFNET
    case 10, % Generates a Scaled 24 node Mesh Topology given in the JSAC Vol.22,No.9
        DisMat=zeros(24);
        DisMat(1,2)=80;DisMat(2,1)=80;
        DisMat(1,6)=100;DisMat(6,1)=100;
        DisMat(2,3)=110;DisMat(3,2)=110;
        DisMat(2,6)=95;DisMat(6,2)=95;
        DisMat(3,4)=25;DisMat(4,3)=25;
        DisMat(3,5)=100;DisMat(5,3)=100;
        DisMat(3,7)=100;DisMat(7,3)=100;
        DisMat(4,5)=80;DisMat(5,4)=80;
        DisMat(4,7)=85;DisMat(7,4)=85;
        DisMat(5,8)=80;DisMat(8,5)=80;
        DisMat(6,7)=100;DisMat(7,6)=100;
        DisMat(6,9)=120;DisMat(9,6)=120;
        DisMat(6,11)=190;DisMat(11,6)=190;
        DisMat(7,9)=100;DisMat(9,7)=100;
        DisMat(7,8)=115;DisMat(8,7)=115;
        DisMat(8,10)=90;DisMat(10,8)=90;
        DisMat(9,10)=100;DisMat(10,9)=100;
        DisMat(9,11)=140;DisMat(11,9)=140;
        DisMat(9,12)=100;DisMat(12,9)=100;
        DisMat(10,13)=95;DisMat(13,10)=95;
        DisMat(10,14)=85;DisMat(14,10)=85;
        DisMat(11,12)=90;DisMat(12,11)=90;
        DisMat(11,15)=130;DisMat(15,11)=130;
        DisMat(12,13)=90;DisMat(13,12)=90;
        DisMat(12,16)=100;DisMat(16,12)=100;
        DisMat(13,14)=65;DisMat(14,13)=65;
        DisMat(13,17)=110;DisMat(17,13)=110;
        DisMat(14,18)=120;DisMat(18,14)=120;
        DisMat(15,16)=60;DisMat(16,15)=60;
        DisMat(15,19)=260;DisMat(19,15)=260;
        DisMat(15,20)=130;DisMat(20,15)=130;
        DisMat(16,17)=100;DisMat(17,16)=100;
        DisMat(16,21)=100;DisMat(21,16)=100;
        DisMat(16,22)=80;DisMat(22,16)=80;
        DisMat(17,18)=80;DisMat(18,17)=80;
        DisMat(17,22)=85;DisMat(22,17)=85;
        DisMat(17,23)=100;DisMat(23,17)=100;
        DisMat(18,24)=90;DisMat(24,18)=90;
        DisMat(19,20)=135;DisMat(20,19)=135; % Orginally in the JSAC paper it is DIS_MAT(19,20)=1200;DIS_MAT(20,19)=1200;
        DisMat(20,21)=70;DisMat(21,20)=70;
        DisMat(21,22)=30;DisMat(22,21)=30;
        DisMat(22,23)=60;DisMat(23,22)=60;
        DisMat(23,24)=90;DisMat(24,23)=90;
        %
        max_degree=0;
        for i=1:length(DisMat)
            degree=0;
            for j=1:length(DisMat)
              if DisMat(i,j)>0
                 number_of_links=number_of_links+1;
                 degree=degree+1;
              end
            end
            max_degree=max(degree,max_degree);
        end
        nds=24;
     case 11, % Generates a US CORONET also called CONUS network toplogy
         DisMat=[ 0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	336.9509334	0	0	761.2090776	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	277.0649613	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	234.2212201	0	0	0	0	0	0	0	0; ...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	1133.443119	647.7371779	0	647.7371779	0	0	0	0	0	0	943.5364333	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	266.2280948	0	0	0	0	439.2379644	0	0	0	0	0	0	0	0	0	0	0	0	554.1108875	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	282.0488176	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	143.5525064	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	179.1949651	0	384.8187539	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	67.17947405	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	500.1517957	0	0	0	0	0	0	0	0	0	0	0	0	147.3504058	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	729.0170987	0	0	0	0	0	0	0	0	0	880.041712	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	848.8579799	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	266.2280948	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	352.382908	582.4644304	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	729.0170987	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	738.9401642	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	277.0649613	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	79.92293577	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	336.4337393	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	126.6263824	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	379.311106	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	430.1818131	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	439.2379644	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	159.8834469	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	459.1452686	0	0	0	0	0	0	0	0	0	0	0	0	0	0	165.3264805	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	357.5730073	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	193.2153767	0	0	0	0	0	0	0	0	0	0	0	0	0	0	177.4925816	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	777.0507392	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	336.4337393	0	0	0	0	0	238.9630572	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	191.2436294	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	193.2153767	238.9630572	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	294.7135669	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    336.9509334	0	1133.443119	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	432.7312491	0	0	0	553.9582807	0	0	0	0	0	0	0	0	0	0	0	0	0	366.9361351	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	647.7371779	0	0	0	0	880.041712	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	920.3373588	0	0	0	0	0	0	0	0	0	0	731.2717231	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	459.1452686	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	107.2436957	0	0	0	0	0;...
                    761.2090776	0	436.9494668	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	964.4531908	0	0	0	0	0	0	0	0	0	0	0	0	0	505.7485307	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	496.1990407	0	0	386.6707817	0	0	0	0	0	0	0	0	0	0	289.9410618	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	159.8834469	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	690.4091794	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	131.0972102	317.8965469	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	186.2707622	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	125.5599482	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	282.0488176	0	500.1517957	0	0	0	0	0	0	0	0	0	0	0	432.7312491	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	554.1108875	0	0	0	0	0	0	0	0	379.311106	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	246.5770348	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	314.0322058	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	470.8657976	0	0	0	0	0	418.4383844	0	0	0;...
                    0	0	943.5364333	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	496.1990407	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	495.9003239	0	0	0	0	0	0	0	700.0051286	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	553.9582807	0	0	0	0	0	0	0	0	0	0	0	0	0	0	261.3433471	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	186.2707622	0	0	0	0	0	0	0	0	0	0	0	0	0	0	29.36152283	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	386.6707817	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	223.8445086	0	0	150.6766134	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	177.4925816	0	0	0	0	0	0	0	690.4091794	0	0	0	0	0	0	0	0	0	0	0	0	0	295.1182142	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	473.8016755	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	261.3433471	0	0	0	0	0	0	0	377.8363294	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	397.1149107	0	0	0	0	129.8250315	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	165.3264805	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	568.3338475	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	738.9401642	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	568.3338475	0	0	0	0	0	0	0	0	561.3270039	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	352.382908	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	295.1182142	377.8363294	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	147.3504058	0	582.4644304	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	653.3593336	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	29.36152283	0	0	0	0	0	0	0	0	0	24.21353477	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	199.5750874	0	0	0	0	0	0	0	0	0	0	0	0	204.1516726;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	24.21353477	0	0	0	0	0	0	136.0604521	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	298.6558234	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	383.6690534;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	289.9410618	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	132.6490217	1135.717402	0	0	25.71991716	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	366.9361351	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	193.3587768	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	920.3373588	0	0	0	0	0	0	0	314.0322058	0	0	0	0	0	0	0	0	561.3270039	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	246.5770348	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	275.7928548	0;...
                    0	0	0	0	0	179.1949651	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	136.0604521	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	193.4089904	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	495.9003239	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	574.6750816	0	0	0	0	0	0	0	0	0	0	0	0	222.4582756	0	0	0	0;...
                    0	0	0	0	0	384.8187539	0	0	0	0	0	0	0	0	0	0	0	294.7135669	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	473.5653806	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	937.7404056	1221.189289	0	0	0	0	0	0	279.0817311	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	79.92293577	0	0	0	0	0	0	0	0	0	0	0	0	0	125.5599482	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	430.1818131	0	0	0	0	0	0	0	0	0	0	131.0972102	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	298.6558234	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	317.8965469	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	190.1446685	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	126.6263824	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	145.265921	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	132.6490217	0	0	0	0	0	0	937.7404056	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	731.2717231	0	0	0	0	0	0	0	0	700.0051286	0	0	0	0	0	0	0	0	0	0	0	0	0	1135.717402	0	0	0	0	0	0	1221.189289	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	143.5525064	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	964.4531908	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	223.8445086	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	574.6750816	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	25.71991716	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	77.16267231	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	77.16267231	0	446.9898708	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	150.6766134	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	446.9898708	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	199.5750874	0	0	0	0	0	0	193.4089904	0	473.5653806	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	223.7750822	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	279.0817311	0	0	0	0	0	0	0	0	0	0	0	0	0	444.2069519	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	848.8579799	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	444.2069519	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	357.5730073	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	144.0599684	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	470.8657976	0	0	0	0	473.8016755	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	144.0599684	0	0	0	0	0	0	0	0	0	0;...
                    0	234.2212201	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	145.265921	0	0	0	0	0	0	0	223.7750822	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	653.3593336	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	394.0942686	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	397.1149107	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	394.0942686	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	191.2436294	0	0	0	107.2436957	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	505.7485307	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	222.4582756	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	418.4383844	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	193.3587768	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	67.17947405	0	0	0	0	0	0	0	0	0	777.0507392	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	190.1446685	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	129.8250315	0	0	0	0	0	0	0	0	0	0	275.7928548	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	204.1516726	0	383.6690534	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0;...
                    ];
         max_degree=0;
         for i=1:length(DisMat)
             degree=0;
             for j=1:length(DisMat)
                if DisMat(i,j)>0
                   number_of_links=number_of_links+1;
                   degree=degree+1;
                end
             end
             max_degree=max(degree,max_degree);
         end
        nds=length(DisMat);
         
end
